---
name: Bug report
about: Create a report to help us improve
title: "[Bug]"
labels: ''
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is. It there is error log, please provide it.

**Screenshots**
The screenshots of Swagger UI if this bug is related to it.

**To Reproduce**
Your code snippet or steps to reproduce the bug.

**Expected behavior**
A clear and concise description of what you expected to happen.

**Environment (please complete the following information):**
 - OS: [e.g. Ubuntu]
 - Browser [e.g. chrome, firefox]
 - Version [e.g. 0.5.3]

**Additional context**
Add any other context about the problem here. This might be how to fix this bug or some hint to fix it.
